[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
branch master updated: gnu: gnupg: Fix cross-compilation.
From: |
guix-commits |
Subject: |
branch master updated: gnu: gnupg: Fix cross-compilation. |
Date: |
Sat, 10 Feb 2024 15:08:01 -0500 |
This is an automated email from the git hooks/post-receive script.
mothacehe pushed a commit to branch master
in repository guix.
The following commit(s) were added to refs/heads/master by this push:
new b64862e5cb gnu: gnupg: Fix cross-compilation.
b64862e5cb is described below
commit b64862e5cb8209c92aa2eff4cec0be328e38c45d
Author: Mathieu Othacehe <othacehe@gnu.org>
AuthorDate: Mon Jan 8 10:54:27 2024 +0100
gnu: gnupg: Fix cross-compilation.
* gnu/packages/gnupg.scm (gnupg)[arguments]: Pass libraries prefixes when
cross-crompiling.
Change-Id: I461ba02ddf5bb23277bd6685c2106e4ad37e2184
Signed-off-by: Mathieu Othacehe <othacehe@gnu.org>
---
gnu/packages/gnupg.scm | 32 +++++++++++++++++++++++++++-----
1 file changed, 27 insertions(+), 5 deletions(-)
diff --git a/gnu/packages/gnupg.scm b/gnu/packages/gnupg.scm
index 171eea6600..9a02635ec1 100644
--- a/gnu/packages/gnupg.scm
+++ b/gnu/packages/gnupg.scm
@@ -346,11 +346,33 @@ compatible to GNU Pth.")
zlib))
(arguments
(list
- #:configure-flags #~'(;; Otherwise, the test suite looks for the `gpg`
- ;; executable in its installation directory in
- ;; /gnu/store before it has been installed.
- "--enable-gnupg-builddir-envvar"
- "--enable-all-tests")
+ #:configure-flags
+ ;; Always use quasiquote on the next core-updates cycle.
+ #~(#$(if (%current-target-system)
+ #~quasiquote
+ #~quote)
+ (#$@(if (%current-target-system)
+ #~(,(string-append
+ "--with-libgpg-error-prefix="
+ #$(this-package-input "libgpg-error"))
+ ,(string-append
+ "--with-libgcrypt-prefix="
+ #$(this-package-input "libgcrypt"))
+ ,(string-append
+ "--with-libassuan-prefix="
+ #$(this-package-input "libassuan"))
+ ,(string-append
+ "--with-ksba-prefix="
+ #$(this-package-input "libksba"))
+ ,(string-append
+ "--with-npth-prefix="
+ #$(this-package-input "npth")))
+ #~())
+ ;; Otherwise, the test suite looks for the `gpg`
+ ;; executable in its installation directory in
+ ;; /gnu/store before it has been installed.
+ "--enable-gnupg-builddir-envvar"
+ "--enable-all-tests"))
#:phases
#~(modify-phases %standard-phases
(add-before 'configure 'patch-paths
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- branch master updated: gnu: gnupg: Fix cross-compilation.,
guix-commits <=